* Output options: all can be turned on/off by adding/ removing the NO;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX NOfmterr;
* Remove default title, turn on new HTML graphics;
  TITLE; ODS GRAPHICS ON;

* Lines that start with * are COMMENTS (notes to yourself);
* Each SAS command (that starts with a BLUE word) must end with a semi-colon;
* Data transformations (e.g., making new variables) must end with a semi-colon;
* USE COLORS TO HELP YOU! Comments are GREEN, SAS system commands are BLUE,
    Variables and file names are BLACK, and if you see RED, something is wrong, 
    Libraries and Labels are PURPLE are case-sensitive and space-sensitive;

* To execute select code, highlight it and hit keyboard short-cut F3 in Windows;

***********************************************************************************;
*******      FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION        *******;
***********************************************************************************;

* Paste in the folder address where "GSS_Example.xlsx" is saved after = before ;
%LET filesave= C:\Dropbox\20FA_PSQF6242\PSQF6242_Example1;
* Using UIowa virtual desktop instead;
*%LET filesave= \\Client\C:\Dropbox\20FA_PSQF6242\PSQF6242_Example1;

* We can then refer to the filesave place by putting & in front and . behind it;

* IMPORT GSS_Example.xlsx data using filesave reference and exact file name;
* from the Excel workbook in DATAFILE= location from SHEET= ;
* New SAS file is in "work" library place with name "Example1";
* "GETNAMES" reads in the first row as variable names;
* DBMS=XLSX (can also use EXCEL or XLS for .xls files);
PROC IMPORT DATAFILE="&filesave.\GSS_Example.xlsx" 
            OUT=work.Example1 DBMS=XLSX REPLACE; 
     SHEET="GSS_Example"; 
     GETNAMES=YES; 
RUN;

* Create formats: set of value labels for categorical variables;
PROC FORMAT;
     VALUE Fmarital 1="1.Married" 2="2.Widowed" 3="3.Divorced"
                       4="4.Separated" 5="5.Never Married";
RUN;

* DATA = create new dataset, SET = from OLD dataset;
* So DATA + SET means "save as itself" after these actions;
* All data transformations must happen inside a DATA+SET+RUN combo;
DATA work.Example1; SET work.Example1;
* Label variables and apply value formats for variables used below;
* LABEL name=      "name: Descriptive Variable Label";
  LABEL marital=   "marital: 5-Category Marital Status"
        educ=      "educ: Years of Education"
        income=    "income: Annual Income in 1000s";
* Apply value labels created above: name Format.;
  FORMAT marital Fmarital.; 
RUN;
* Now datset work.Example1 is ready to use; 

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example1_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

***********************************************************************************;
*******              BEGIN EXAMPLE 1 UNIVARIATE STATISTICS                  *******;
***********************************************************************************;

* TITLE prints in output, to remove, just TITLE again;

* PROC FREQ prints frequency tables for categorical variables;
* TABLE = variables to use, MISSING includes missing values too;
TITLE "Frequency Table and Plot for Categorical Variable marital";
PROC FREQ DATA=work.Example1;               
     TABLE marital / MISSING PLOTS=FREQPLOT(TYPE=BAR SCALE=PERCENT);  
RUN; TITLE; 

* PROC MEANS prints sample descriptive statistics for quantitative variables; 
* NDEC= controls number of decimal places, VAR lists variables;
TITLE "Univariate Statistics for Quantitative Variable income";
PROC MEANS NDEC=3 N MEAN STDDEV VAR MIN MAX DATA=work.Example1;
     VAR income;
RUN; TITLE;
 
* PROC UNIVARIATE gives more sample statistics and also makes histograms; 
* You can also control the midpoints (see example below);
TITLE "More Univariate Statistics and Histogram for Quantitative Variable income";
PROC UNIVARIATE DATA=work.Example1;
     VAR income;
     HISTOGRAM income / MIDPOINTS=0 TO 70 BY 5;
RUN; TITLE;

***********************************************************************************;
*******                BEGIN EXAMPLE 1 UNIVARIATE TESTS OF MEANS            *******;
***********************************************************************************;

* TTEST to compare sample mean to H0=expected at alpha=.05;
* CI=equal also requests confidence interval for SD;
TITLE "Is the mean of education different than 12 years?";
PROC TTEST DATA=work.Example1 HO=12 SIDES=2 ALPHA=.05 CI=EQUAL PLOTS=NONE;
     VAR educ;
RUN; TITLE;

* To test the proprotion of high school non-graduates or graduates; 
* we will need to make 2 new variables using conditional logic;
DATA work.Example1; SET work.Example1;
     lessHS=.; * First create 2 new empty variables;
     gradHS=.;  
     * Second assign their values using conditional logic;
       IF educ>0 AND educ<12 THEN lessHS=1;
       IF educ>0 AND educ<12 THEN gradHS=0;
       IF educ>=12           THEN lessHS=0; 
       IF educ>=12           THEN gradHS=1;
RUN;

* FREQ compare proportion to BINOMIAL P=expected at alpha=.05;
* Specify LEVEL= to test proportion of 1 values against H0;
* CL requests confidence interval for proportion;

TITLE "Is the proportion of HS non-graduates different than .10?";
PROC FREQ DATA=work.Example1;
     TABLE lessHS / CL BINOMIAL(LEVEL="1" P=.10) ALPHA=.05;
RUN; TITLE;

TITLE "Is the proportion of HS graduates different than .90?";
PROC FREQ DATA=work.Example1;
     TABLE gradHS / CL BINOMIAL(LEVEL="1" P=.90) ALPHA=.05;
RUN; 
PROC FREQ DATA=work.Example1;
     TABLE lessHS / CL BINOMIAL(LEVEL="0" P=.90) ALPHA=.05;
RUN; TITLE;
* Either PROC FREQ creates the same result;

***********************************************************************************;
* Close output;
ODS RTF CLOSE;
 
